@@ -3,7 +3,7 @@
 """
 from sys import argv
 from os import getenv
-from os.path import exists as path_exists
+from os.path import exists as path_exists, isfile
 from json import dumps as json_dump, loads as json_load
 import argparse
 from config import __version__
@@ -11,6 +11,12 @@ from config import __version__
 new_element = None
 
 
+def __dump_json__(file_path, json):
+    # TODO: перейти на использование этого метода во всех методах
+    with open(file_path, 'w') as file:
+        file.write(json_dump(json, indent=4))
+
+
 def __parse_element__(element, name_parent_element, parent_element):
     global new_element
     if element['type'] == 'object':
@@ -22,7 +28,44 @@ def __parse_element__(element, name_parent_element, parent_element):
         parent_element[name_parent_element] = element.get('default')
 
 
+def __update_add_command__(params, template):
+    # TODO: сделать проверку на существование элемента и запрашивать перезапись
+    with open(params.config_file, 'r') as config_file:
+        config = json_load(config_file.read())
+    for i in params.elements:
+        if i not in template['properties']:
+            print(f'Элемента {i} нет в шаблоне')
+            return
+        global new_element
+        new_element = {}
+        __parse_element__(template['properties'][i], i, new_element)
+        config[i] = new_element[i]
+
+    with open(params.config_file, 'w') as file_config:
+        file_config.write(json_dump(config, indent=4))
+    print(f"{'Элемент добавлен' if len(params.elements) == 1 else 'Элементы добавлены'}")
+
+
+def __update_delete_command__(params, template):
+    with open(params.config_file, 'r') as config_file:
+        config = json_load(config_file.read())
+
+    for i in params.elements:
+        if i in config.keys():
+            del config[i]
+            print(f"{i} элемент удален")
+        else:
+            print(f"{i} элемент отсутсвует в конфиге")
+
+    __dump_json__(params.config_file, config)
+
+    print('Удаление выполнено')
+
+
 def create_command(params):
+    """
+    Команда создания конфига из шаблона
+    """
     default_config = {
         "logging": {
             "level_logging": "ERROR",
@@ -104,12 +147,36 @@ def create_command(params):
     print('Конфигурация создана')
 
 
+def update_command(params):
+    """
+    Команда обновления конфига
+    """
+    if not getenv('TEMPLATE_CONFIG', default=None):
+        print("Не определена переменная окружения TEMPLATE_CONFIG")
+        return
+    if not path_exists(params.config_file) and not isfile(params.config_file):
+        print("Указанного файла не существует")
+        return
+
+    # TODO: в удаление шаблон не используется исправить
+    template = json_load(open(getenv("TEMPLATE_CONFIG")).read())
+    update_methods = {
+        "add": __update_add_command__,
+        "delete": __update_delete_command__
+    }
+    update_methods[params.update_command](params, template)
+
+
 methods = {
-    "create": create_command
+    "create": create_command,
+    "update": update_command
 }
 
 
 def create_parse():
+    """
+    Команда создания парсинга аргументов
+    """
     parser = argparse.ArgumentParser(add_help=False)
 
     parent_group = parser.add_argument_group(title="Параметры")
@@ -121,6 +188,7 @@ def create_parse():
                                        description="Команды, которые должны быть в качестве первого параметра %(prog)s")
 
     create_command_parser = subparsers.add_parser("create", add_help=False)
+    # TODO: изменить тип
     create_command_parser.add_argument('config_file', type=argparse.FileType(mode='w'))
     create_command_parser.add_argument('-e', '--elements', nargs='+', help="Элементы, которые нужно добавить в конфиг. "
                                                                            "Для работы этого параметра требуется "
@@ -129,11 +197,17 @@ def create_parse():
     create_command_parser.add_argument('--list-elements', action='store_true', default=False)
     create_command_parser.add_argument('-h', '--help', action='help', help='Справка')
 
+    update_command_parser = subparsers.add_parser('update', add_help=False)
+    update_command_parser.add_argument('config_file')
+    update_command_parser.add_argument('update_command', choices=['add', 'delete'])
+    update_command_parser.add_argument('elements', nargs='+')
+    update_command_parser.add_argument('-h', '--help', action='help', help='Справка')
+
     return parser
 
 
 if __name__ == '__main__':
-    parser = create_parse()
-    parsed_params = parser.parse_args(argv[1:])
+    main_parser = create_parse()
+    parsed_params = main_parser.parse_args(argv[1:])
 
     methods[parsed_params.command](parsed_params)
